ReceiveTrafficState

Enum ReceiveTrafficState 

pub enum ReceiveTrafficState<'a, Side: SideData> {
    ReadMore(ReceiveTraffic<Side>),
    FlushSender(FlushSender<Side>),
    Available(ReceivedApplicationData<'a, Side>),
    CloseNotify,
}
A state machine that cycles between requiring further received TLS data and discharging received application data.

Each call to ReceiveTraffic::read() returns one of these states, and each non-terminal state lets you obtain the next one: ReadMore by supplying more input and calling read() again, and FlushSender / Available through their into_next() methods. CloseNotify is terminal.

           ╭────────────────╮
  ╭───────▶│ ReceiveTraffic │
  │        ╰───────┬────────╯
ReadMore           │ read(&mut input)
  │                ▼
  ╰────╭───────────────────────╮
       │  ReceiveTrafficState  │──── CloseNotify ────▶ (terminal)
  ╭───▶╰──┬────────────────────╯
  │       │              │
  │  FlushSender      Available
  │  .into_next()    .into_next()
  │       │              │
  ╰───────┴──────────────╯

Variants



ReadMore(ReceiveTraffic<Side>)

More input is required.

Collect it into your input buffer, and then call ReceiveTraffic::read() again.



FlushSender(FlushSender<Side>)

The sender may have new data to send.



Available(ReceivedApplicationData<'a, Side>)

Some application data has been received.



CloseNotify

We received a close_notify alert from the peer.

This means the receive path is closed cleanly.