FlushSender

Struct FlushSender 

pub struct FlushSender<Side: SideData> { /* private fields */ }
Notification that receiving data may have changed the state of the associated SendTraffic

The caller may wish to check whether there is any IO necessary on the send side. If it does not, and ignores this state, any pending new data to send will be included in the next attempt to send data.

Implementations

Source

impl<Side: SideData> FlushSender<Side>

pub fn into_next(self) -> ReceiveTrafficState<'static, Side>

Obtain the next receive-side state.