ReceiveTraffic

Struct ReceiveTraffic 

pub struct ReceiveTraffic<Side: SideData> { /* private fields */ }
The receive-side of a connection, after a successful handshake.

You can use this object to receive data from the peer.

Implementations

Source

impl<Side: SideData> ReceiveTraffic<Side>

pub fn read<'a>( self, input: &'a mut impl TlsInputBuffer, ) -> Result<ReceiveTrafficState<'a, Side>, ErrorWithAlert>

Receive application data from the peer.

received_tls is an instance of the receive buffer abstraction containing TLS-protected data received from the peer.

A ReceiveTrafficState is returned on success.

An error from this function permanently breaks the ability to receive data from the peer. The error may be accompanied by a TLS alert, which can be obtained from the returned ErrorWithAlert and sent to the peer. Following this, the underlying IO medium should be closed by the application.

Source

impl ReceiveTraffic<ClientSide>

pub fn tls13_tickets_received(&self) -> u32

Returns the number of TLS1.3 tickets that have been received.